package Bundle::Locale::CLDR::Micronesianregion;

use version;

our $VERSION = version->declare('v0.34.1');

=head1 NAME Bundle::Locale::CLDR::Micronesianregion

=head1 CONTENTS

Locale::CLDR::Locales::En::Any 0.34.1
Locale::CLDR::Locales::En::Any::Fm 0.34.1
Locale::CLDR::Locales::En::Any::Gu 0.34.1
Locale::CLDR::Locales::En::Any::Ki 0.34.1
Locale::CLDR::Locales::En::Any::Mh 0.34.1
Locale::CLDR::Locales::En::Any::Mp 0.34.1
Locale::CLDR::Locales::En::Any::Nr 0.34.1
Locale::CLDR::Locales::En::Any::Pw 0.34.1
Locale::CLDR::Locales::En::Any::Um 0.34.1
Locale::CLDR::Locales::En::Any::001 0.34.1

=cut

1;

